Blob Blame History Raw
diff -urN fontmatrix-0.9.99-Source.old/fontmatrix.1 fontmatrix-0.9.99-Source/fontmatrix.1
--- fontmatrix-0.9.99-Source.old/fontmatrix.1	2011-10-03 11:32:54.357203868 +0530
+++ fontmatrix-0.9.99-Source/fontmatrix.1	2013-01-08 21:27:30.704581547 +0530
@@ -53,10 +53,10 @@
 User preferences are stored in $HOME/.fontmatrix/ on Unix or Linux. Most other paths are configurable from the Fontmatrix preferences. 
 .B $HOME/.fonts/
 .TP 
-.B $HOME/.fonts.conf
+.B $HOME/.config/fontconfig/fonts.conf
 .TP 
 .B /etc/fonts
-Fontconfig, the library used by Fontmatrix to locate fonts, is normally configured with files in /etc/fonts, mainly /etc/fonts/fonts.conf and /etc/fonts/local.conf . It may also use a config file $HOME/.fonts.conf and fonts in $HOME/.fonts/ . See fonts.conf(5) and the fontconfig documentation for more information. Note that Fontmatrix may also use its internal font path to locate more fonts \- see the Preferences dialog and fontmatrix help.
+Fontconfig, the library used by Fontmatrix to locate fonts, is normally configured with files in /etc/fonts, mainly /etc/fonts/fonts.conf and /etc/fonts/local.conf . It may also use a config file $HOME/.config/fontconfig/fonts.conf and fonts in $HOME/.fonts/ . See fonts.conf(5) and the fontconfig documentation for more information. Note that Fontmatrix may also use its internal font path to locate more fonts \- see the Preferences dialog and fontmatrix help.
 .SH "RELATED SOFTWARE AND AFFILIATES"
 Scribus \- http://www.scribus.net
 
diff -urN fontmatrix-0.9.99-Source.old/src/fmactivate.cpp fontmatrix-0.9.99-Source/src/fmactivate.cpp
--- fontmatrix-0.9.99-Source.old/src/fmactivate.cpp	2011-10-03 11:32:54.428204383 +0530
+++ fontmatrix-0.9.99-Source/src/fmactivate.cpp	2013-01-08 20:58:56.616642198 +0530
@@ -285,7 +285,7 @@
 bool FMActivate::addFcReject(const QString & path)
 {
 #ifdef HAVE_FONTCONFIG
-	QFile fcfile ( QDir::homePath() + "/.fonts.conf" );
+	QFile fcfile ( QDir::homePath() + "/.config/fontconfig/fonts.conf" );
 	if ( !fcfile.open ( QFile::ReadWrite ) )
 	{
 		qWarning()<<"Cannot open"<< fcfile.fileName();
@@ -380,7 +380,7 @@
 bool FMActivate::remFcReject(const QString & path)
 {
 #ifdef HAVE_FONTCONFIG
-	QFile fcfile ( QDir::homePath() + "/.fonts.conf" );
+	QFile fcfile ( QDir::homePath() + "/.config/fontconfig/fonts.conf" );
 	if ( !fcfile.open ( QFile::ReadWrite ) )
 	{
 		return false;
diff -urN fontmatrix-0.9.99-Source.old/src/fmactivate.h fontmatrix-0.9.99-Source/src/fmactivate.h
--- fontmatrix-0.9.99-Source.old/src/fmactivate.h	2011-10-03 11:32:54.434204428 +0530
+++ fontmatrix-0.9.99-Source/src/fmactivate.h	2013-01-08 20:58:16.264618945 +0530
@@ -52,7 +52,7 @@
 		
 	private:
 		/*
-		Add and Remove fonts in ~/.fonts.conf
+		Add and Remove fonts in ~/.config/fontconfig/fonts.conf
 		with <selecfont><rejectfont><glob> sequence
 		*/
 		bool addFcReject(const QString& path);
diff -urN fontmatrix-0.9.99-Source.old/src/typotek.cpp fontmatrix-0.9.99-Source/src/typotek.cpp
--- fontmatrix-0.9.99-Source.old/src/typotek.cpp	2011-10-03 11:32:54.366203934 +0530
+++ fontmatrix-0.9.99-Source/src/typotek.cpp	2013-01-08 20:59:58.561676631 +0530
@@ -1093,7 +1093,7 @@
 void typotek::addFcDirItem(const QString & dirPath)
 {
 #ifdef HAVE_FONTCONFIG
-	QFile fcfile ( QDir::homePath() + "/.fonts.conf" );
+	QFile fcfile ( QDir::homePath() + "/.config/fontconfig/fonts.conf" );
 	if ( !fcfile.open ( QFile::ReadWrite ) )
 	{
 		return;
@@ -1102,7 +1102,7 @@
 	{
 		QDomDocument fc ( "fontconfig" );
 
 		// .fonts.conf is empty, it seems that we just created it.
 		// Wed have to populate it a bit
 		if ( fcfile.size() == 0 )
 		{
@@ -1102,7 +1102,7 @@
 		QDomDocument fc ( "fontconfig" );
 
-		// .fonts.conf is empty, it seems that we just created it.
+		// ~/.config/fontconfig/fonts.conf is empty, it seems that we just created it.
 		// Wed have to populate it a bit
 		if ( fcfile.size() == 0 )